@@ -344,9 +344,11 @@ isochron <- function(fn, params, data, s2d, settings, cex) {
         args$growth <- pd$growth
     }
     if (gc == "U-Pb") {
-        args$type <- pd$UPbtype;
         if (params$gcsettings$format > 3) {
             args$joint <- pd$joint
+            args$type <- pd$UPbtype
+        } else {
+            args$type <- 2
         }
         args$y0option <- pd$UPb_y0option
     }
@@ -656,7 +658,7 @@ age <- function(fn, params, data, s2d, settings) {
 #'
 #' Opens a web-browser with a Graphical User Interface (GUI) for the
 #' \code{IsoplotR} package. An online version of the same interface is
-#' provided at \url{https://www.ucl.ac.uk/~ucfbpve/isoplotr/}
+#' provided at \url{https://isoplotr.es.ucl.ac.uk/}
 #' @param host IP address of the virtual server, default is 0.0.0.0
 #' @param port Internet port of the virtual server. If not defined, a
 #'     random free port will be chosen and the browser will be opened
